# vacancy_rate_and_population_in_JP_and_USA
アメリカと日本の空き家率や人口について、1958年から2018年まで5年ごとのデータを棒グラフや折れ線グラフを用いて、分析した。

## Data
日本の空き家率データ：総務省統計局の住宅・土地統計調査住宅数概数集計結果<br>
日本の人口データ：国立社会保障・人口問題研究所、The World Bank

- https://www.stat.go.jp/data/jyutaku/2018/tyousake.html
- https://www.ipss.go.jp/syoushika/tohkei/Data/Relation/1_Future/1_doukou/1-1-A01.htm
- https://datacommons.org/place/country/JPN?utm_medium=explore&mprop=count&popt=Person&hl=ja

アメリカの空き家率データ：FRED ECONOMIN DATA<br>
アメリカの人口データ：The World Bank

- https://fred.stlouisfed.org/series/RHVRNEQ156N
- https://datacommons.org/place/country/USA?category=Demographics&hl=ja

## インストールと実行方法
```
$ pip install vacanthouse
$ vacanthouse
```

## 出力
<img src="https://raw.githubusercontent.com/Lifengtong1/vacancy_rate_and_population_in_JP_and_USA/blob/main/result.png"